==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'بالانتظار',
	'articles_meme_auteur' => 'كل مقالات هذا المؤلف',
	'articles_off' => 'مصدودة',
	'articles_publie' => 'منشورة',
	'articles_refuse' => 'محذوفة',
	'articles_tous' => 'الكل',
	'aucun_article_syndic' => 'لا توجد مقالات مرخصة',
	'avis_echec_syndication_01' => 'الترخيص فشل: فإما لا يمكن قراءة ملف الترخيص الخلفي أو أنه لا يوفر أي مقال.',
	'avis_echec_syndication_02' => 'الترخيص فشل: ليس من الممكن الوصول إلى ملف الترخيص الخلفي في هذا الموقع.',
	'avis_site_introuvable' => 'الموقع غير موجود',
	'avis_site_syndique_probleme' => 'تحذير: ترخيص هذا الموقع واجه مشكلة؛ بالتالي فالنظام متوقف بشكل مؤقت. الرجاء التأكد من عنوان ملف ترخيص هذا الموقع (<b>@url_syndic@</b>)، ومحاولة تنفيذ عملية استرجاع معلومات جديدة.',
	'avis_sites_probleme_syndication' => 'هذه المواقع واجهت مشكلة ترخيص',
	'avis_sites_syndiques_probleme' => 'ظهرت مشاكل في هذه المواقع المرخصة',

	// B
	'bouton_exporter' => 'نقل',
	'bouton_importer' => 'جلب',
	'bouton_radio_modere_posteriori' => 'مراقبة بعدية',
	'bouton_radio_modere_priori' => 'مراقبة استباقية',
	'bouton_radio_non_syndication' => 'عدم ترخيص',
	'bouton_radio_syndication' => 'ترخيص:',

	// C
	'confirmer_purger_syndication' => 'هل تريد فعلاً حذف كل المقالات المرخصة في هذا الموقع؟',

	// E
	'entree_adresse_fichier_syndication' => 'عنوان ملف الترخيص:',
	'entree_adresse_site' => '<b>عنوان الموقع</b> [إجباري]',
	'entree_description_site' => 'وصف الموقع',
	'erreur_fichier_format_inconnu' => 'تنسيق الملف @fichier@ غير مدعوم.',
	'erreur_fichier_incorrect' => 'لا يمكن قراءة الملف.',

	// F
	'form_prop_nom_site' => 'اسم الموقع',

	// I
	'icone_article_syndic' => 'مقال مرخص',
	'icone_articles_syndic' => 'مقالات مرخصة',
	'icone_controler_syndication' => 'نشر المقالات المرخصة',
	'icone_modifier_site' => 'تعديل الموقع',
	'icone_referencer_nouveau_site' => 'تبويب موقع جديد',
	'icone_site_reference' => 'مواقع مبوبة',
	'icone_supprimer_article' => 'حذف هذا المقال',
	'icone_supprimer_articles' => 'حذف هذه المقالات',
	'icone_valider_article' => 'التصديق على هذا المقال',
	'icone_valider_articles' => 'التصديق على هذه المقالات',
	'icone_voir_sites_references' => 'عرض المواقع المبوبة',
	'info_1_site_importe' => 'تم جلب موقع واحد',
	'info_a_valider' => '[بانتظار التصديق]',
	'info_aucun_site_importe' => 'لم يتم جلب اي موقع',
	'info_bloquer' => 'إيقاف',
	'info_bloquer_lien' => 'صد هذه الوصلة',
	'info_derniere_syndication' => 'تم تنفيذ آخر ترخيص لهذا الموقع في',
	'info_liens_syndiques_1' => 'وصلة مرخصة',
	'info_liens_syndiques_2' => 'تنتظر التصديق.',
	'info_nb_sites_importes' => 'تم جلب @nb@ موقع',
	'info_nom_site_2' => '<b>إسم الموقع</b> [إجباري]',
	'info_panne_site_syndique' => 'موقع مرخص معطل',
	'info_probleme_grave' => 'مشكلة',
	'info_question_proposer_site' => 'من يمكنه اقتراح مواقع مبوبة؟',
	'info_retablir_lien' => 'استرجاع هذه الوصلة',
	'info_site_attente' => 'موقع بانتظار التصديق',
	'info_site_propose' => 'موقع مقترح بتاريخ:',
	'info_site_reference' => 'موقع مبوب على النسيج',
	'info_site_refuse' => 'موقع مرفوض',
	'info_site_syndique' => 'هذا الموقع مرخص...',
	'info_site_valider' => 'مواقع تنتظر التصديق',
	'info_sites_referencer' => 'تبويب موقع',
	'info_sites_refuses' => 'المواقع المرفوضة',
	'info_statut_site_1' => 'هذا الموقع:',
	'info_statut_site_2' => 'منشور',
	'info_statut_site_3' => 'مقترح',
	'info_statut_site_4' => 'الى المهملات',
	'info_syndication' => 'ترخيص:',
	'info_syndication_articles' => 'مقال',
	'item_bloquer_liens_syndiques' => 'صد الوصلات المرخصة بانتظار تصديقها',
	'item_gerer_annuaire_site_web' => 'إدارة دليل للمواقع',
	'item_non_bloquer_liens_syndiques' => 'عدم صد الوصلات الآتية من الترخيص',
	'item_non_gerer_annuaire_site_web' => 'ايقاف دليل المواقع',
	'item_non_utiliser_syndication' => 'عدم استخدام الترخيص الآلي',
	'item_utiliser_syndication' => 'إستخدام الترخيص الآلي',

	// L
	'label_exporter_avec_mots_cles_1' => 'نقل المفاتيح على شكل علامات',
	'label_exporter_id_parent' => 'نقل مواقع القسم',
	'label_exporter_publie_seulement_1' => 'نقل المواقع المنشورة فقط',
	'label_fichier_import' => 'ملف HTML',
	'label_importer_les_tags_1' => 'جلب العلامات على شكل مفاتيح',
	'label_importer_statut_publie_1' => 'نشر المواقع آلياً',
	'lien_mise_a_jour_syndication' => 'تحديث الآن',
	'lien_nouvelle_recuperation' => 'محاولة تنفيذ إسترجاع جديد للبيانات',
	'lien_purger_syndication' => 'حذف كل المقالات المرخصة',

	// N
	'nombre_articles_syndic' => '@nb@ مقال مرخص',

	// S
	'statut_off' => 'محذوف',
	'statut_prop' => 'بالانتظار',
	'statut_publie' => 'منشور',
	'syndic_choix_moderation' => 'ماذا تريد ان تفعل بالوصلات المقبلة القادمة من هذا الموقع؟',
	'syndic_choix_oublier' => 'ماذا تريد ان تفعل بالوصلات التي لم تعد واردة في ملف الترخيص؟',
	'syndic_choix_resume' => 'هناك بعض المواقع التي تنشر النص الكامل لمقالاتها. فإذا كان هذا النص متوافراً، عل تريد ترخيص:',
	'syndic_lien_obsolete' => 'وصلة قديمة',
	'syndic_option_miroir' => 'ايقافها آلياً',
	'syndic_option_oubli' => 'حذفها (بعد @mois@ شهر)',
	'syndic_option_resume_non' => 'النص الكامل للمقال (بتنسيق HTML)',
	'syndic_option_resume_oui' => 'ملخص بسيط (بتنسيق نص)',
	'syndic_options' => 'خيارات الترخيص:',

	// T
	'texte_expliquer_export_bookmarks' => 'يمكنك نقل لائحة بالمواقع بتنسيق مرجعيات HTML،
لتتمكن لاحقاً من جلبها في برنامج التصفح او في اي خدمة على النسيج',
	'texte_expliquer_import_bookmarks' => 'يمكنك جلب لائحة بالمواقع بتنسيق مرجعيات HTML،
من برنامج التصفح او من اي خدمة إدارة مرجعيات على النسيج.',
	'texte_liens_sites_syndiques' => 'يمكن صد الروابط الآتية من المواقع المرخصة استباقياً؛ ويعرض الخيار التالي الإعداد الافتراضي للمواقع المرخصة بعد إنشائها. عندها، يصبح من الممكن فتح كل رابط بمفرده او اختيار صد كل الروابط الآتية من اي موقع معين بمفرده.',
	'texte_messages_publics' => 'المشاركات العامة على هذا المقال:',
	'texte_non_fonction_referencement' => 'يمكنك تفضيل عدم استخدام هذه الوظيفة الآلية والقيام بإدخال العناصر المتعلقة بهذا الموقع بنفسك...',
	'texte_referencement_automatique' => '<b>تبويب المواقع الآلي</b><br />يمكنك تبويب موقع ما سريعاً بإدخال عنوانه أدناه أو عنوان ملف الترخيص الخلفي لديه. سيقوم SPIP آلياً بجلب المعلومات المتعلقة بهذا الموقع (الإسم والوصف...).',
	'texte_referencement_automatique_verifier' => 'الرجاء التأكد من المعلومات التي يوفرها <tt>@url@</tt> قيل الحفظ.',
	'texte_syndication' => 'إذا كان أحد المواقع يسمح بذلك، يمكن للنظام ان يقوم آلياً بجلب قائمة بأحدث ما نُشر في هذا الموقع. لإتمام ذلك يجب تفعيل الترخيص.
  &lt;blockquote&gt;بعض خدام المواقع يعطلون هذه الوظيفة. في هذه الحال لا يمكنك الاستفادة من ترخيص محتوى المواقع من موقعك. &lt;/blockquote&gt;',
	'titre_articles_syndiques' => 'المقالات المرخصة المسحوبة من هذا الموقع',
	'titre_dernier_article_syndique' => 'أحدث المقالات المرخصة',
	'titre_exporter_bookmarks' => 'نقل مرجعيات',
	'titre_importer_bookmarks' => 'جلب مرجعيات',
	'titre_importer_exporter_bookmarks' => 'جلب ونقل مرجعيات',
	'titre_page_sites_tous' => 'المواقع المبوبة',
	'titre_referencement_sites' => 'تبويب وترخيص المواقع',
	'titre_site_numero' => 'موقع رقم:',
	'titre_sites_proposes' => 'المواقع المقترحة',
	'titre_sites_references_rubrique' => 'المواقع المبوبة في هذا القسم',
	'titre_sites_syndiques' => 'المواقع المرخصة',
	'titre_sites_tous' => 'المواقع المبوبة',
	'titre_syndication' => 'ترخيص المواقع',
	'tout_voir' => 'عرض كل المقالات المرخصة',

	// U
	'un_article_syndic' => 'مقال مرخص واحد'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'بالانتظار',
	'articles_meme_auteur' => 'كل مقالات هذا المؤلف',
	'articles_off' => 'مصدودة',
	'articles_publie' => 'منشورة',
	'articles_refuse' => 'محذوفة',
	'articles_tous' => 'الكل',
	'aucun_article_syndic' => 'لا توجد مقالات مرخصة',
	'avis_echec_syndication_01' => 'الترخيص فشل: فإما لا يمكن قراءة ملف الترخيص الخلفي أو أنه لا يوفر أي مقال.',
	'avis_echec_syndication_02' => 'الترخيص فشل: ليس من الممكن الوصول إلى ملف الترخيص الخلفي في هذا الموقع.',
	'avis_site_introuvable' => 'الموقع غير موجود',
	'avis_site_syndique_probleme' => 'تحذير: ترخيص هذا الموقع واجه مشكلة؛ بالتالي فالنظام متوقف بشكل مؤقت. الرجاء التأكد من عنوان ملف ترخيص هذا الموقع (<b>@url_syndic@</b>)، ومحاولة تنفيذ عملية استرجاع معلومات جديدة.',
	'avis_sites_probleme_syndication' => 'هذه المواقع واجهت مشكلة ترخيص',
	'avis_sites_syndiques_probleme' => 'ظهرت مشاكل في هذه المواقع المرخصة',

	// B
	'bouton_exporter' => 'نقل',
	'bouton_importer' => 'جلب',
	'bouton_radio_modere_posteriori' => 'مراقبة بعدية',
	'bouton_radio_modere_priori' => 'مراقبة استباقية',
	'bouton_radio_non_syndication' => 'عدم ترخيص',
	'bouton_radio_syndication' => 'ترخيص:',

	// C
	'confirmer_purger_syndication' => 'هل تريد فعلاً حذف كل المقالات المرخصة في هذا الموقع؟',

	// E
	'entree_adresse_fichier_syndication' => 'عنوان ملف الترخيص:',
	'entree_adresse_site' => '<b>عنوان الموقع</b> [إجباري]',
	'entree_description_site' => 'وصف الموقع',
	'erreur_fichier_format_inconnu' => 'تنسيق الملف @fichier@ غير مدعوم.',
	'erreur_fichier_incorrect' => 'لا يمكن قراءة الملف.',

	// F
	'form_prop_nom_site' => 'اسم الموقع',

	// I
	'icone_article_syndic' => 'مقال مرخص',
	'icone_articles_syndic' => 'مقالات مرخصة',
	'icone_controler_syndication' => 'نشر المقالات المرخصة',
	'icone_modifier_site' => 'تعديل الموقع',
	'icone_referencer_nouveau_site' => 'تبويب موقع جديد',
	'icone_site_reference' => 'مواقع مبوبة',
	'icone_supprimer_article' => 'حذف هذا المقال',
	'icone_supprimer_articles' => 'حذف هذه المقالات',
	'icone_valider_article' => 'التصديق على هذا المقال',
	'icone_valider_articles' => 'التصديق على هذه المقالات',
	'icone_voir_sites_references' => 'عرض المواقع المبوبة',
	'info_1_article_syndique' => 'مقال مرخص واحد',
	'info_1_site' => 'موقع واحد',
	'info_1_site_importe' => 'تم جلب موقع واحد',
	'info_a_valider' => '[بانتظار التصديق]',
	'info_aucun_article_syndique' => 'لا مقال مرخص',
	'info_aucun_site' => 'لا موقع',
	'info_aucun_site_importe' => 'لم يتم جلب اي موقع',
	'info_bloquer' => 'إيقاف',
	'info_bloquer_lien' => 'صد هذه الوصلة',
	'info_derniere_syndication' => 'تم تنفيذ آخر ترخيص لهذا الموقع في',
	'info_liens_syndiques_1' => 'وصلة مرخصة',
	'info_liens_syndiques_2' => 'تنتظر التصديق.',
	'info_nb_articles_syndiques' => '@nb@ مقال مرخص',
	'info_nb_sites' => '@nb@ موقع',
	'info_nb_sites_importes' => 'تم جلب @nb@ موقع',
	'info_nom_site_2' => '<b>إسم الموقع</b> [إجباري]',
	'info_panne_site_syndique' => 'موقع مرخص معطل',
	'info_probleme_grave' => 'مشكلة',
	'info_question_proposer_site' => 'من يمكنه اقتراح مواقع مبوبة؟',
	'info_retablir_lien' => 'استرجاع هذه الوصلة',
	'info_site_attente' => 'موقع بانتظار التصديق',
	'info_site_propose' => 'موقع مقترح بتاريخ:',
	'info_site_reference' => 'موقع مبوب على النسيج',
	'info_site_refuse' => 'موقع مرفوض',
	'info_site_syndique' => 'هذا الموقع مرخص...',
	'info_site_valider' => 'مواقع تنتظر التصديق',
	'info_sites_referencer' => 'تبويب موقع',
	'info_sites_refuses' => 'المواقع المرفوضة',
	'info_statut_site_1' => 'هذا الموقع:',
	'info_statut_site_2' => 'منشور',
	'info_statut_site_3' => 'مقترح',
	'info_statut_site_4' => 'الى المهملات',
	'info_syndication' => 'ترخيص:',
	'info_syndication_articles' => 'مقال',
	'item_bloquer_liens_syndiques' => 'صد الوصلات المرخصة بانتظار تصديقها',
	'item_gerer_annuaire_site_web' => 'إدارة دليل للمواقع',
	'item_non_bloquer_liens_syndiques' => 'عدم صد الوصلات الآتية من الترخيص',
	'item_non_gerer_annuaire_site_web' => 'ايقاف دليل المواقع',
	'item_non_utiliser_syndication' => 'عدم استخدام الترخيص الآلي',
	'item_utiliser_syndication' => 'إستخدام الترخيص الآلي',

	// L
	'label_exporter_avec_mots_cles_1' => 'نقل المفاتيح على شكل علامات',
	'label_exporter_id_parent' => 'نقل مواقع القسم',
	'label_exporter_publie_seulement_1' => 'نقل المواقع المنشورة فقط',
	'label_fichier_import' => 'ملف HTML',
	'label_importer_les_tags_1' => 'جلب العلامات على شكل مفاتيح',
	'label_importer_statut_publie_1' => 'نشر المواقع آلياً',
	'lien_mise_a_jour_syndication' => 'تحديث الآن',
	'lien_nouvelle_recuperation' => 'محاولة تنفيذ إسترجاع جديد للبيانات',
	'lien_purger_syndication' => 'حذف كل المقالات المرخصة',

	// N
	'nombre_articles_syndic' => '@nb@ مقال مرخص',

	// S
	'statut_off' => 'محذوف',
	'statut_prop' => 'بالانتظار',
	'statut_publie' => 'منشور',
	'syndic_choix_moderation' => 'ماذا تريد ان تفعل بالوصلات المقبلة القادمة من هذا الموقع؟',
	'syndic_choix_oublier' => 'ماذا تريد ان تفعل بالوصلات التي لم تعد واردة في ملف الترخيص؟',
	'syndic_choix_resume' => 'هناك بعض المواقع التي تنشر النص الكامل لمقالاتها. فإذا كان هذا النص متوافراً، عل تريد ترخيص:',
	'syndic_lien_obsolete' => 'وصلة قديمة',
	'syndic_option_miroir' => 'ايقافها آلياً',
	'syndic_option_oubli' => 'حذفها (بعد @mois@ شهر)',
	'syndic_option_resume_non' => 'النص الكامل للمقال (بتنسيق HTML)',
	'syndic_option_resume_oui' => 'ملخص بسيط (بتنسيق نص)',
	'syndic_options' => 'خيارات الترخيص:',

	// T
	'texte_expliquer_export_bookmarks' => 'يمكنك نقل لائحة بالمواقع بتنسيق مرجعيات HTML،
لتتمكن لاحقاً من جلبها في برنامج التصفح او في اي خدمة على النسيج',
	'texte_expliquer_import_bookmarks' => 'يمكنك جلب لائحة بالمواقع بتنسيق مرجعيات HTML،
من برنامج التصفح او من اي خدمة إدارة مرجعيات على النسيج.',
	'texte_liens_sites_syndiques' => 'يمكن صد الروابط الآتية من المواقع المرخصة استباقياً؛ ويعرض الخيار التالي الإعداد الافتراضي للمواقع المرخصة بعد إنشائها. عندها، يصبح من الممكن فتح كل رابط بمفرده او اختيار صد كل الروابط الآتية من اي موقع معين بمفرده.',
	'texte_messages_publics' => 'المشاركات العامة على هذا المقال:',
	'texte_non_fonction_referencement' => 'يمكنك تفضيل عدم استخدام هذه الوظيفة الآلية والقيام بإدخال العناصر المتعلقة بهذا الموقع بنفسك...',
	'texte_referencement_automatique' => '<b>تبويب المواقع الآلي</b><br />يمكنك تبويب موقع ما سريعاً بإدخال عنوانه أدناه أو عنوان ملف الترخيص الخلفي لديه. سيقوم SPIP آلياً بجلب المعلومات المتعلقة بهذا الموقع (الإسم والوصف...).',
	'texte_referencement_automatique_verifier' => 'الرجاء التأكد من المعلومات التي يوفرها <tt>@url@</tt> قيل الحفظ.',
	'texte_syndication' => 'إذا كان أحد المواقع يسمح بذلك، يمكن للنظام ان يقوم آلياً بجلب قائمة بأحدث ما نُشر في هذا الموقع. لإتمام ذلك يجب تفعيل الترخيص.
  &lt;blockquote&gt;بعض خدام المواقع يعطلون هذه الوظيفة. في هذه الحال لا يمكنك الاستفادة من ترخيص محتوى المواقع من موقعك. &lt;/blockquote&gt;',
	'titre_articles_syndiques' => 'المقالات المرخصة المسحوبة من هذا الموقع',
	'titre_dernier_article_syndique' => 'أحدث المقالات المرخصة',
	'titre_exporter_bookmarks' => 'نقل مرجعيات',
	'titre_importer_bookmarks' => 'جلب مرجعيات',
	'titre_importer_exporter_bookmarks' => 'جلب ونقل مرجعيات',
	'titre_page_sites_tous' => 'المواقع المبوبة',
	'titre_referencement_sites' => 'تبويب وترخيص المواقع',
	'titre_site_numero' => 'موقع رقم:',
	'titre_sites_proposes' => 'المواقع المقترحة',
	'titre_sites_references_rubrique' => 'المواقع المبوبة في هذا القسم',
	'titre_sites_syndiques' => 'المواقع المرخصة',
	'titre_sites_tous' => 'المواقع المبوبة',
	'titre_syndication' => 'ترخيص المواقع',
	'tout_voir' => 'عرض كل المقالات المرخصة',

	// U
	'un_article_syndic' => 'مقال مرخص واحد'
);

?>
